@@ -3,11 +3,12 @@ from __future__ import annotations
 import concurrent
 import logging
 from abc import ABC
+from collections import defaultdict, deque
 from concurrent.futures import Executor, Future
 from datetime import datetime, timezone
-from functools import lru_cache
-from threading import Lock
-from typing import ClassVar, Dict, Optional, List, Type, Any, TypeVar, Callable, Iterator
+from functools import lru_cache, reduce
+from threading import Lock, Event
+from typing import ClassVar, Dict, Optional, List, Type, Any, TypeVar, Callable, Iterator, Deque, Tuple
 
 from attr import evolve, field
 from attrs import define
@@ -31,6 +32,8 @@ from resotolib.core.actions import CoreFeedback
 from resotolib.graph import Graph, EdgeKey, ByNodeId, BySearchCriteria, NodeSelector
 from resotolib.json import to_json as to_js, from_json as from_js
 from resotolib.json_bender import Bender, bend
+from resotolib.lock import RWLock
+from resotolib.proc import set_thread_name
 from resotolib.types import Json
 
 log = logging.getLogger("resoto.plugins.aws")
@@ -324,51 +327,148 @@ class CancelOnFirstError(Exception):
     pass
 
 
+class GatherFutures:
+    def __init__(self, futures: List[Future[Any]]) -> None:
+        self._futures = futures
+        self._lock = Lock()
+        self._to_wait = len(futures)
+        self._when_done: Future[None] = Future()
+        for future in futures:
+            future.add_done_callback(self._on_future_done)
+
+    def _on_future_done(self, _: Future[Any]) -> None:
+        with self._lock:
+            self._to_wait -= 1
+            if self._to_wait == 0:
+                self._when_done.set_result(None)
+
+    @staticmethod
+    def all(futures: List[Future[Any]]) -> Future[None]:
+        return GatherFutures(futures)._when_done
+
+
+@define
+class ExecutorQueueTask:
+    key: Any
+    fn: Callable[..., T]
+    args: Tuple[Any, ...]
+    kwargs: Dict[str, Any]
+    future: Future[Any]
+
+    def __call__(self) -> T:  # type: ignore
+        try:
+            result: T = self.fn(*self.args, **self.kwargs)
+            self.future.set_result(result)
+            return result
+        except Exception as e:
+            self.future.set_exception(e)
+            raise
+
+
 @define
 class ExecutorQueue:
-    executor: Executor
-    name: str
-    fail_on_first_exception: bool = False
-    futures: List[Future[Any]] = field(factory=list)
-    _lock: Lock = Lock()
-    _exception: Optional[Exception] = None
+    """
+    Use an underlying executor to perform work in parallel, but limit the number of tasks per key.
+    If fail_on_first_exception_in_group is True, then the first exception in a group
+    will not execute any more tasks in the same group.
+    """
 
-    def submit_work(self, fn: Callable[..., T], *args: Any, **kwargs: Any) -> Future[T]:
-        def do_work() -> T:
+    executor: Executor
+    tasks_per_key: Callable[[str], int]
+    name: str
+    fail_on_first_exception_in_group: bool = False
+    _tasks_lock: Lock = Lock()
+    _tasks: Dict[str, Deque[ExecutorQueueTask]] = field(factory=lambda: defaultdict(deque))
+    _in_progress: Dict[str, int] = field(factory=lambda: defaultdict(int))
+    _futures: List[Future[Any]] = field(factory=list)
+    _exceptions: Dict[Any, Exception] = field(factory=dict)
+    _task_finished: Event = Event()
+
+    def submit_work(self, key: Any, fn: Callable[..., T], *args: Any, **kwargs: Any) -> Future[T]:
+        future = Future[T]()
+        task = ExecutorQueueTask(key=key, fn=fn, args=args, kwargs=kwargs, future=future)
+        self.__append_work(task)
+        return future
+
+    def __append_work(self, task: ExecutorQueueTask) -> None:
+        with self._tasks_lock:
+            self._tasks[task.key].appendleft(task)
+            self.__check_queue(task.key)
+
+    def __check_queue(self, key: Any) -> None:
+        # note: this method is not thread safe, it should only be called from within a lock
+        in_progress = self._in_progress[key]
+        tasks = self._tasks[key]
+
+        if self.fail_on_first_exception_in_group and self._exceptions.get(key) is not None:
+            # Fail all tasks in this group
+            ex = CancelOnFirstError("Exception happened in another thread. Do not start work.")
+            for task in tasks:
+                task.future.set_exception(ex)
+            # Clear the queue, so we don't execute them
+            # Clear the queue, so we don't execute them
+            tasks.clear()
+
+        if in_progress < self.tasks_per_key(key) and tasks:
+            task = tasks.pop()
+            self._in_progress[key] += 1
+            self.__perform_task(task)
+
+    def __perform_task(self, task: ExecutorQueueTask) -> Future[T]:
+        def only_start_when_no_error() -> T:
             # in case of exception let's fail fast and do not execute the function
-            if self._exception is None:
+            if self._exceptions.get(task.key) is None:
                 try:
-                    return fn(*args, **kwargs)
+                    return task()
                 except Exception as e:
                     # only store the first exception if we should fail on first future
-                    if self._exception is None:
-                        self._exception = e
+                    if self._exceptions.get(task.key) is None:
+                        self._exceptions[task.key] = e
                     raise e
             else:
                 raise CancelOnFirstError(
                     "Exception happened in another thread. Do not start work."
-                ) from self._exception
+                ) from self._exceptions[task.key]
 
-        future = (
-            self.executor.submit(do_work) if self.fail_on_first_exception else self.executor.submit(fn, *args, **kwargs)
-        )
+        def execute() -> T:
+            try:
+                return only_start_when_no_error() if self.fail_on_first_exception_in_group else task()
+            finally:
+                with self._tasks_lock:
+                    self._in_progress[task.key] -= 1
+                    self._task_finished.set()
+                    self.__check_queue(task.key)
 
-        with self._lock:
-            self.futures.append(future)
+        future = self.executor.submit(execute)
+
+        self._futures.append(future)
         return future
 
     def wait_for_submitted_work(self) -> None:
         # wait until all futures are complete
-        with self._lock:
-            to_wait = self.futures
-            self.futures = []
+        to_wait = []
+
+        # step 1: wait until all tasks are committed to the executor
+        while True:
+            with self._tasks_lock:
+                ip = reduce(lambda x, y: x + y, self._in_progress.values(), 0)
+                if ip == 0:
+                    to_wait = self._futures
+                    self._futures = []
+                    break
+                else:
+                    # safe inside the lock. clear this event and check when next task is done
+                    self._task_finished.clear()
+            self._task_finished.wait()
+
+        # step 2: wait for all tasks to complete
         for future in concurrent.futures.as_completed(to_wait):
             try:
                 future.result()
             except CancelOnFirstError:
                 pass
             except Exception as ex:
-                log.exception(f"Unhandled exception in account {self.name}: {ex}")
+                log.exception(f"Unhandled exception in {self.name}: {ex}")
                 raise
 
 
@@ -383,6 +483,8 @@ class GraphBuilder:
         executor: ExecutorQueue,
         core_feedback: CoreFeedback,
         global_instance_types: Optional[Dict[str, Any]] = None,
+        graph_nodes_access: Optional[RWLock] = None,
+        graph_edges_access: Optional[RWLock] = None,
     ) -> None:
         self.graph = graph
         self.cloud = cloud
@@ -393,13 +495,21 @@ class GraphBuilder:
         self.name = f"AWS:{account.name}:{region.name}"
         self.global_instance_types: Dict[str, Any] = global_instance_types if global_instance_types is not None else {}
         self.core_feedback = core_feedback
+        self.graph_nodes_access = graph_nodes_access or RWLock()
+        self.graph_edges_access = graph_edges_access or RWLock()
 
-    def submit_work(self, fn: Callable[..., None], *args: Any, **kwargs: Any) -> Future[Any]:
+    def submit_work(self, service: str, fn: Callable[..., T], *args: Any, **kwargs: Any) -> Future[T]:
         """
         Use this method for work that can be done in parallel.
-        Example: fetching tags of a resource.
+        Note: the executor pool is shared between all regions and only allows the configured number of tasks per key.
+              Key: RegionId:Service in the same region and the same service start only the configured number of tasks
         """
-        return self.executor.submit_work(fn, *args, **kwargs)
+
+        def fn_wrapper() -> T:
+            set_thread_name(f"aws_{self.account.id}_{self.region.id}_{service}")
+            return fn(*args, **kwargs)
+
+        return self.executor.submit_work(self.region.id + ":" + service, fn_wrapper)
 
     @property
     def config(self) -> AwsConfig:
@@ -408,17 +518,19 @@ class GraphBuilder:
     def node(self, clazz: Optional[Type[AwsResourceType]] = None, **node: Any) -> Optional[AwsResourceType]:
         if isinstance(nd := node.get("node"), AwsResource):
             return nd  # type: ignore
-        for n in self.graph:
-            is_clazz = isinstance(n, clazz) if clazz else True
-            if is_clazz and all(getattr(n, k, None) == v for k, v in node.items()):
-                return n  # type: ignore
+        with self.graph_nodes_access.read_access:
+            for n in self.graph:
+                is_clazz = isinstance(n, clazz) if clazz else True
+                if is_clazz and all(getattr(n, k, None) == v for k, v in node.items()):
+                    return n  # type: ignore
         return None
 
     def nodes(self, clazz: Optional[Type[AwsResourceType]] = None, **node: Any) -> Iterator[AwsResourceType]:
-        for n in self.graph:
-            is_clazz = isinstance(n, clazz) if clazz else True
-            if is_clazz and all(getattr(n, k, None) == v for k, v in node.items()):
-                yield n
+        with self.graph_nodes_access.read_access:
+            for n in self.graph:
+                is_clazz = isinstance(n, clazz) if clazz else True
+                if is_clazz and all(getattr(n, k, None) == v for k, v in node.items()):
+                    yield n
 
     def add_node(
         self, node: AwsResourceType, source: Optional[Json] = None, region: Optional[AwsRegion] = None
@@ -430,11 +542,12 @@ class GraphBuilder:
         :param region: only define the region in case it is different from the region of the graph builder.
         :return: the added node
         """
-        log.debug(f"{self.name}: add node {node}")
+        log.debug(f"Added node {node.kdname}")
         node._cloud = self.cloud
         node._account = self.account
         node._region = region or self.region
-        self.graph.add_node(node, source=source or {})
+        with self.graph_nodes_access.write_access:
+            self.graph.add_node(node, source=source or {})
         return node
 
     def add_edge(
@@ -443,8 +556,8 @@ class GraphBuilder:
         to_n = self.node(**to_node)
         if isinstance(from_node, AwsResource) and isinstance(to_n, AwsResource):
             start, end = (to_n, from_node) if reverse else (from_node, to_n)
-            log.debug(f"{self.name}: add edge: {start} -> {end} [{edge_type}]")
-            self.graph.add_edge(start, end, edge_type=edge_type)
+            with self.graph_edges_access.write_access:
+                self.graph.add_edge(start, end, edge_type=edge_type)
 
     def add_deferred_edge(
         self, from_node: BaseResource, edge_type: EdgeType, to_node: str, reverse: bool = False
@@ -461,23 +574,26 @@ class GraphBuilder:
         if isinstance(from_node, AwsResource) and isinstance(to_n, AwsResource):
             start, end = (to_n, from_node) if reverse else (from_node, to_n)
             log.debug(f"{self.name}: add edge: {start} -> {end} [default]")
-            self.graph.add_edge(start, end, edge_type=EdgeType.default)
-            if delete_same_as_default:
-                start, end = end, start
-            log.debug(f"{self.name}: add edge: {end} -> {start} [delete]")
-            self.graph.add_edge(end, start, edge_type=EdgeType.delete)
+            with self.graph_edges_access.write_access:
+                self.graph.add_edge(start, end, edge_type=EdgeType.default)
+                if delete_same_as_default:
+                    start, end = end, start
+                log.debug(f"{self.name}: add edge: {end} -> {start} [delete]")
+                self.graph.add_edge(end, start, edge_type=EdgeType.delete)
 
     def resources_of(self, resource_type: Type[AwsResourceType]) -> List[AwsResourceType]:
-        return [n for n in self.graph.nodes if isinstance(n, resource_type)]
+        with self.graph_nodes_access.read_access:
+            return [n for n in self.graph.nodes if isinstance(n, resource_type)]
 
     def edges_of(
         self, from_type: Type[AwsResource], to_type: Type[AwsResource], edge_type: EdgeType = EdgeType.default
     ) -> List[EdgeKey]:
-        return [
-            key
-            for (from_node, to_node, key) in self.graph.edges
-            if isinstance(from_node, from_type) and isinstance(to_node, to_type) and key.edge_type == edge_type
-        ]
+        with self.graph_edges_access.read_access:
+            return [
+                key
+                for (from_node, to_node, key) in self.graph.edges
+                if isinstance(from_node, from_type) and isinstance(to_node, to_type) and key.edge_type == edge_type
+            ]
 
     @lru_cache(maxsize=None)
     def instance_type(self, region: AwsRegion, instance_type: str) -> Optional[Any]:
@@ -514,4 +630,6 @@ class GraphBuilder:
             self.executor,
             self.core_feedback,
             self.global_instance_types,
+            self.graph_nodes_access,
+            self.graph_edges_access,
         )
